==> haskell-warp-tls-3.2.4.3-124-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.4.3
id: warp-tls-3.2.4.3-A95Yvr5rJKnGyKlezqOZAW
key: warp-tls-3.2.4.3-A95Yvr5rJKnGyKlezqOZAW
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
abi: 32554b7ed1a1e30fe9ca80a4f9c06f66
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
import-dirs: /usr/lib/ghc-8.6.3/site-local/warp-tls-3.2.4.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/warp-tls-3.2.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/warp-tls-3.2.4.3
hs-libraries: HSwarp-tls-3.2.4.3-A95Yvr5rJKnGyKlezqOZAW
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cryptonite-0.25-5E9EuEAz1M1JrY25iIyNbL
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
    streaming-commons-0.2.1.0-98A77q62kI8Fyxj1zEbMgD
    tls-1.4.1-FxojR1y3h491i0IUBCfdzv
    tls-session-manager-0.0.0.2-AU3iunItjusMo4xLggfRf
    wai-3.2.1.2-5o435cLCPoFEkqFQ2eloj
    warp-3.2.25-DaocYfaS4Y24BVlQNfZJ4T
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.2.4.3-126-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.4.3
id: warp-tls-3.2.4.3-3BeLDdkANTqDYLuoXdh4ms
key: warp-tls-3.2.4.3-3BeLDdkANTqDYLuoXdh4ms
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
abi: 7a22cfcfa46dcf6da603cad254daea68
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
import-dirs: /usr/lib/ghc-8.6.3/site-local/warp-tls-3.2.4.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/warp-tls-3.2.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/warp-tls-3.2.4.3
hs-libraries: HSwarp-tls-3.2.4.3-3BeLDdkANTqDYLuoXdh4ms
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cryptonite-0.25-5E9EuEAz1M1JrY25iIyNbL
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
    streaming-commons-0.2.1.0-98A77q62kI8Fyxj1zEbMgD
    tls-1.4.1-FxojR1y3h491i0IUBCfdzv
    tls-session-manager-0.0.0.2-AU3iunItjusMo4xLggfRf
    wai-3.2.1.2-5o435cLCPoFEkqFQ2eloj
    warp-3.2.25-L90jch8gFEGKgMMnxO6akk
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
